==> v1.8.3.tar.gz: osv-scanner-1.8.3/internal/utility/vulns/vulnerabilities_test.go <==
package vulns_test

import (
	"testing"

	"github.com/google/osv-scanner/internal/utility/vulns"
	"github.com/google/osv-scanner/pkg/models"
)

func TestVulnerabilities_Includes(t *testing.T) {
	t.Parallel()

	type args struct {
		osv models.Vulnerability
	}
	tests := []struct {
		name string
		vs   models.Vulnerabilities
		args args
		want bool
	}{
		{
			name: "",
			vs: models.Vulnerabilities{
				models.Vulnerability{
					ID:      "GHSA-1",
					Aliases: []string{},
				},
			},
			args: args{
				osv: models.Vulnerability{
					ID:      "GHSA-2",
					Aliases: []string{},
				},
			},
			want: false,
		},
		{
			name: "",
			vs: models.Vulnerabilities{
				models.Vulnerability{
					ID:      "GHSA-1",
					Aliases: []string{},
				},
			},
			args: args{
				osv: models.Vulnerability{
					ID:      "GHSA-1",
					Aliases: []string{},
				},
			},
			want: true,
		},
		{
			name: "",
			vs: models.Vulnerabilities{
				models.Vulnerability{
					ID:      "GHSA-1",
					Aliases: []string{"GHSA-2"},
				},
			},
			args: args{
				osv: models.Vulnerability{
					ID:      "GHSA-2",
					Aliases: []string{},
				},
			},
			want: true,
		},
		{
			name: "",
			vs: models.Vulnerabilities{
				models.Vulnerability{
					ID:      "GHSA-1",
					Aliases: []string{},
				},
			},
			args: args{
				osv: models.Vulnerability{
					ID:      "GHSA-2",
					Aliases: []string{"GHSA-1"},
				},
			},
			want: true,
		},
		{
			name: "",
			vs: models.Vulnerabilities{
				models.Vulnerability{
					ID:      "GHSA-1",
					Aliases: []string{"CVE-1"},
				},
			},
			args: args{
				osv: models.Vulnerability{
					ID:      "GHSA-2",
					Aliases: []string{"CVE-1"},
				},
			},
			want: true,
		},
		{
			name: "",
			vs: models.Vulnerabilities{
				models.Vulnerability{
					ID:      "GHSA-1",
					Aliases: []string{"CVE-2"},
				},
			},
			args: args{
				osv: models.Vulnerability{
					ID:      "GHSA-2",
					Aliases: []string{"CVE-2"},
				},
			},
			want: true,
		},
	}
	for _, tt := range tests {
		tt := tt
		t.Run(tt.name, func(t *testing.T) {
			t.Parallel()

			if got := vulns.Include(tt.vs, tt.args.osv); got != tt.want {
				t.Errorf("Includes() = %v, want %v", got, tt.want)
			}
		})
	}
}

==> v2.1.0.tar.gz: osv-scanner-2.1.0/internal/utility/vulns/vulnerabilities_test.go <==
package vulns_test

import (
	"testing"

	"github.com/google/osv-scanner/v2/internal/utility/vulns"
	"github.com/ossf/osv-schema/bindings/go/osvschema"
)

func TestVulnerabilities_Includes(t *testing.T) {
	t.Parallel()

	type args struct {
		osv osvschema.Vulnerability
	}
	tests := []struct {
		name string
		vs   []*osvschema.Vulnerability
		args args
		want bool
	}{
		{
			name: "",
			vs: []*osvschema.Vulnerability{
				{
					ID:      "GHSA-1",
					Aliases: []string{},
				},
			},
			args: args{
				osv: osvschema.Vulnerability{
					ID:      "GHSA-2",
					Aliases: []string{},
				},
			},
			want: false,
		},
		{
			name: "",
			vs: []*osvschema.Vulnerability{
				{
					ID:      "GHSA-1",
					Aliases: []string{},
				},
			},
			args: args{
				osv: osvschema.Vulnerability{
					ID:      "GHSA-1",
					Aliases: []string{},
				},
			},
			want: true,
		},
		{
			name: "",
			vs: []*osvschema.Vulnerability{
				{
					ID:      "GHSA-1",
					Aliases: []string{"GHSA-2"},
				},
			},
			args: args{
				osv: osvschema.Vulnerability{
					ID:      "GHSA-2",
					Aliases: []string{},
				},
			},
			want: false,
		},
		{
			name: "",
			vs: []*osvschema.Vulnerability{
				{
					ID:      "GHSA-1",
					Aliases: []string{},
				},
			},
			args: args{
				osv: osvschema.Vulnerability{
					ID:      "GHSA-2",
					Aliases: []string{"GHSA-1"},
				},
			},
			want: false,
		},
		{
			name: "",
			vs: []*osvschema.Vulnerability{
				{
					ID:      "GHSA-1",
					Aliases: []string{"CVE-1"},
				},
			},
			args: args{
				osv: osvschema.Vulnerability{
					ID:      "GHSA-2",
					Aliases: []string{"CVE-1"},
				},
			},
			want: false,
		},
		{
			name: "",
			vs: []*osvschema.Vulnerability{
				{
					ID:      "GHSA-1",
					Aliases: []string{"CVE-2"},
				},
			},
			args: args{
				osv: osvschema.Vulnerability{
					ID:      "GHSA-2",
					Aliases: []string{"CVE-2"},
				},
			},
			want: false,
		},
	}
	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			t.Parallel()

			if got := vulns.Include(tt.vs, tt.args.osv); got != tt.want {
				t.Errorf("Includes() = %v, want %v", got, tt.want)
			}
		})
	}
}
